@@ -18,8 +18,8 @@ public:
   size_t* CopyList();
 
   size_t Length();
+  size_t Capacity();
   void Fill();
-  void Reset();
   void Resize(const size_t);
   void Shuffle();
 
